package hu.bme.mit.bookmanager.gui;

import hu.bme.mit.books.manager.BookManager;
import hu.bme.mit.books.model.Book;

import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.part.ViewPart;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Spinner;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.layout.RowData;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;

public class BookDetailView extends ViewPart {

	public static final String ID = "hu.bme.mit.bookmanager.gui.BookDetailView"; //$NON-NLS-1$
	private Text authorText;
	private Text titleText;
	private Spinner pageNumSpinner;
	private Button readCheck;
	private Label bookCounterLabel;
	private BookManager manager;
	private int selectedBookId = 0;
	private Button nextButton;
	private Button prevButton;

	public BookDetailView() {
		manager = new BookManager();
	}

	/**
	 * Create contents of the view part.
	 * @param parent
	 */
	@Override
	public void createPartControl(Composite parent) {
		Composite container = new Composite(parent, SWT.NONE);
		container.setLayout(new GridLayout(1, false));
		{
			Group grpBookInformation = new Group(container, SWT.NONE);
			grpBookInformation.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
			grpBookInformation.setText("Book Information");
			grpBookInformation.setLayout(new GridLayout(3, false));
			{
				Label label = new Label(grpBookInformation, SWT.NONE);
				label.setText("Author");
			}
			new Label(grpBookInformation, SWT.NONE);
			{
				authorText = new Text(grpBookInformation, SWT.BORDER);
				authorText.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
			}
			{
				Label label = new Label(grpBookInformation, SWT.NONE);
				label.setText("Title");
			}
			new Label(grpBookInformation, SWT.NONE);
			{
				titleText = new Text(grpBookInformation, SWT.BORDER);
				titleText.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
			}
			{
				Label label = new Label(grpBookInformation, SWT.NONE);
				label.setText("Pages");
			}
			new Label(grpBookInformation, SWT.NONE);
			{
				pageNumSpinner = new Spinner(grpBookInformation, SWT.BORDER);
				pageNumSpinner.setLayoutData(new GridData(SWT.LEFT, SWT.FILL, true, false, 1, 1));
			}
			new Label(grpBookInformation, SWT.NONE);
			new Label(grpBookInformation, SWT.NONE);
			{
				readCheck = new Button(grpBookInformation, SWT.CHECK);
				readCheck.setLayoutData(new GridData(SWT.LEFT, SWT.FILL, true, false, 1, 1));
				readCheck.setText("Already read");
			}
		}
		{
			Composite composite = new Composite(container, SWT.NONE);
			composite.setLayout(new FillLayout(SWT.HORIZONTAL));
			
			prevButton = new Button(composite, SWT.NONE);
			prevButton.addSelectionListener(new SelectionAdapter() {
				@Override
				public void widgetSelected(SelectionEvent e) {
					if (selectedBookId > 0) {
						selectedBookId --;
						selectBook();
					}
				}
			});
			prevButton.setText("<< Prev");
			
			bookCounterLabel = new Label(composite, SWT.NONE);
			bookCounterLabel.setAlignment(SWT.CENTER);
			bookCounterLabel.setText(" 0 / 0");
			
			nextButton = new Button(composite, SWT.NONE);
			nextButton.addSelectionListener(new SelectionAdapter() {
				@Override
				public void widgetSelected(SelectionEvent e) {
					if (selectedBookId < manager.getNumberOfBooks() - 1) {
						selectedBookId ++;
						selectBook();
					}
				}
			});
			nextButton.setText("Next >>");
		}

		createActions();
		initializeToolBar();
		initializeMenu();
		
		selectedBookId = 0;
		selectBook();
	}
	
	private void selectBook() {
		Book book = manager.getBookOfID(selectedBookId);
		if (book != null) {
			authorText.setText(book.getAuthor());
			titleText.setText(book.getTitle());
			pageNumSpinner.setSelection(book.getPageNum());
			readCheck.setSelection(book.isRead());
			bookCounterLabel.setText(String.format("%d/%d", selectedBookId + 1, manager.getNumberOfBooks()));
			prevButton.setEnabled(selectedBookId != 0);
			nextButton.setEnabled(selectedBookId != manager.getNumberOfBooks() - 1);
		}
	}

	/**
	 * Create the actions.
	 */
	private void createActions() {
		// Create the actions
	}

	/**
	 * Initialize the toolbar.
	 */
	private void initializeToolBar() {
		IToolBarManager toolbarManager = getViewSite().getActionBars()
				.getToolBarManager();
	}

	/**
	 * Initialize the menu.
	 */
	private void initializeMenu() {
		IMenuManager menuManager = getViewSite().getActionBars()
				.getMenuManager();
	}

	@Override
	public void setFocus() {
		// Set the focus
	}
}
